Grid Class
==========

General Grids 
^^^^^^^^^^^^^

.. autoclass:: emiproc.grids.Grid

.. autoclass:: emiproc.grids.RegularGrid

.. autoclass:: emiproc.grids.GeoPandasGrid


Model Grids 
^^^^^^^^^^^

.. autoclass:: emiproc.exports.wrf.WRF_Grid

.. autoclass:: emiproc.grids.ICONGrid
